@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/Channel.tcl,v $
-# $Date: 1998/06/12 15:04:18 $
-# $Revision: 1.18.1.162 $
+# $Date: 1998/06/24 11:13:32 $
+# $Revision: 1.18.1.164 $
 #
 #
 package provide zircon 1.18
@@ -446,10 +446,12 @@ proc channel_configure {this args} {
 	switch -glob -- $name {
 	-history {
 	    switch {} $val { set val 50 }
+	    if {$val < 0} { set val 0 }
 	    set cdata(history) $val
 	}
 	-scrollback {
 	    switch {} $val { set val 0 }
+	    if {$val < 0} { set val 0 }
 	    set cdata(scrollback) $val
 	}
 	-ban {
@@ -509,6 +511,7 @@ for regular expression \"$v\" in -ban for channel [$this name]"
 		}
 	    }
 	-closetime {
+		if {$val < 0} {set val 0}
 		set ct [expr {$val * 1000}]
 		if {$ct > 0 && $ct < [[$this net] testTime]} {
 		    [$this net] configure -testTime $ct
@@ -1464,7 +1467,7 @@ proc wsortIns {chan win un usr args} {
     set top text
     set wd [$win cget -width]
     switch nil [set fr [$usr fobj]] {} default {
-        switch {} [set fg [$fr image]] {} default {
+        switch {} [set fg [$fr images]] {} default {
            set top image
 	   set img [lindex $fg 0]
 	   set wd {}
