@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/Classes.tcl,v $
-# $Date: 1998/06/12 15:04:20 $
-# $Revision: 1.18.1.80 $
+# $Date: 1998/06/24 11:13:34 $
+# $Revision: 1.18.1.82 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -204,6 +204,7 @@ class Friend {
     usr		nil
     ison	0
     limbo	0
+    images	{}
 }
 #
 global zircon
@@ -234,6 +235,7 @@ class Net "
     popInfo	0	{bool {Pop Up Info}}
     undernet	0	{bool {Undernet Server}}
     srvcycle	0	{bool {Try All Servers}}
+    lagmeter	0	{Bool {Display Lag Meter}}
     autoclearaway 0	{bool}
     cleargone   0	{bool}
     norestrict	0	{bool}
