@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/Net.tcl,v $
-# $Date: 1998/06/22 14:37:01 $
-# $Revision: 1.18.1.141 $
+# $Date: 1998/06/24 11:13:41 $
+# $Revision: 1.18.1.142 $
 #
 package provide zircon 1.18
 #
@@ -90,6 +90,12 @@ proc net_configure {this args} {
     foreach {opt val} $args {
 	set name [string range $opt 1 end]
 	switch -glob -- $opt {
+	-lagmeter {
+		if {$val && $ndata(ping) == 0} {
+		    set ndata(ping) 30000
+		}
+		set ndata(lagmeter) $val
+	    }
 	-toInfo -
 	-noconfirm {
 		set ndata($name) {}
@@ -650,15 +656,23 @@ proc net_isonTest {this} {
 proc net_pingTest {this} {
     upvar #0 $this ndata
     set nm [$this host]
-    if {$ndata(pinged)} {
+    if {$ndata(pinged) != 0} {
 	$this close "Server $nm is not responding - closing the connection"
     } {
 	$this PING $nm
-	set ndata(pinged) 1
+	set ndata(pinged) [clock seconds]
 	after $ndata(ping) "$this pingTest"
     }
 }
 #
+proc net_handlePong {this} {
+    upvar #0 $this ndata
+    if {$ndata(lagmeter)} {
+        [$this control] lag [expr {[clock seconds] - $ndata(pinged)}]
+    }
+    set ndata(pinged) 0
+}
+#
 proc Net_list {} { global znetList ; return $znetList }
 #
 proc net_setMode {this chan mode args} {
