@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Util.tcl,v $
-# $Date: 1998/04/27 11:46:05 $
-# $Revision: 1.18.1.65 $
+# $Date: 1998/05/22 12:53:17 $
+# $Revision: 1.18.1.68 $
 #
 package provide zircon 1.18
 #
@@ -94,9 +94,6 @@ proc me {nk net} {
     return 0
 }
 #
-set ctcpCmds  {Clientinfo Finger Ping Time Version Userinfo Other}
-set specialCmds {Zircon}
-#
 proc addCTCPMenu {net name usr} {
     global ctcpCmds DEBUG specialCmds
     $name add cascade -label [trans ctcp] -menu $name.ctcp
@@ -571,25 +568,48 @@ proc palIns {char chan prt} {
 }
 #
 proc popPalette {m chn prt col x y} {
-    global mIRCCol
+    global mIRCCol vt100Colour
     if {![winfo exists $m]} {
 	menu $m -tearoff 0
-	$m add command -label Bold -command "palIns \002 {$chn} {$prt}"
-	$m add command -label Inverse -command "palIns \026 {$chn} {$prt}"
-	$m add command -label Underline -command "palIns \037 {$chn} {$prt}"
-	$m add command -label Normal -command "palIns \017 {$chn} {$prt}"
-        switch {} $col {} default {
-	    $m add cascade -label Foreground -menu $m.fg
-	    $m add cascade -label Background -menu $m.bg
-	    menu $m.fg -tearoff 0
-	    foreach x {0 1 2 3 4 5 6 7 8 9 10 12 12 13 14 15} {
-		$m.fg add command -background $mIRCCol($x) \
-		   -command "palIns {\003$x} {$chn} {$prt}"
-	    }
-	    menu $m.bg -tearoff 0
-	    foreach x {0 1 2 3 4 5 6 7 8 9 10 12 12 13 14 15} {
-		$m.bg add command -background $mIRCCol($x) \
-		   -command "bgIns $x {$chn} {$prt}"
+	$m add command -label [trans bold] -command "palIns \002 {$chn} {$prt}"
+	$m add command -label [trans inverse] -command "palIns \026 {$chn} {$prt}"
+	$m add command -label [trans underline] -command "palIns \037 {$chn} {$prt}"
+	$m add command -label [trans normal] -command "palIns \017 {$chn} {$prt}"
+        foreach x $col {
+	    switch $x mirc {
+	        $m add separator
+		$m add command -label {mIRC Colour}
+	        $m add cascade -label [trans foreground] -menu $m.fg
+	        $m add cascade -label [trans background] -menu $m.bg
+	        menu $m.fg -tearoff 0
+		set cls [lsort [array names mIRCCol]]
+	        foreach x $cls {
+		    $m.fg add command -background $mIRCCol($x) \
+		       -command "palIns {\003$x} $chn [list $prt]"
+	        }
+	        menu $m.bg -tearoff 0
+	        foreach x $cls {
+		    $m.bg add command -background $mIRCCol($x) \
+		       -command "bgIns $x $chn [list $prt]"
+	        }
+	    } ansi {
+	        $m add separator
+		$m add command -label {ANSI Colour}
+	        $m add cascade -label [trans foreground] -menu $m.vfg
+	        $m add cascade -label [trans background] -menu $m.vbg
+	        menu $m.vfg -tearoff 0
+	        foreach x {0 1 2 3 4 5 6 7} {
+		    $m.vfg add command -background $vt100Colour($x) \
+		       -command "palIns {\033\[3${x}m} {$chn} {$prt}"
+	        }
+	        menu $m.vbg -tearoff 0
+	        foreach x {0 1 2 3 4 5 6 7} {
+		    $m.vbg add command -background $vt100Colour($x) \
+		       -command "palIns {\033\[4${x}m} {$chn} {$prt}"
+	        }
+	    } ctcp2 {
+	        $m add separator
+		$m add command -label {CTCP2 Colour}
 	    }
 	}
     }
@@ -598,11 +618,10 @@ proc popPalette {m chn prt col x y} {
 #
 proc makePalette {w chn prt name ft col} {
     if {[winfo exists $w]} {popup $w ; return} 
-    global mIRCCol Ft
+    global Ft
     killWindow $w
     toplevel $w -class Zircon
     wm title $w "$name Palette"
-    wm protocol $w WM_DELETE_WINDOW "destroy $w"
     wm resizable $w 0 0
     set row 0
     switch {} $ft {set ft [$prt cget -font]}
@@ -617,31 +636,57 @@ proc makePalette {w chn prt name ft col} {
 	incr row
     }
     grid [frame $w.s0] -columnspan 16 -pady 4
-    incr row 1
+    incr row
     foreach {x y} {Bold \002 Inverse \026 Underline \037 Normal \017} {
 	button $w.f$x -text $x -width 10 -command "palIns $y {$chn} {$prt}"
     }
     grid $w.fBold $w.fInverse $w.fUnderline $w.fNormal -columnspan 4
-    switch {} $col {} default {
-	grid [frame $w.s1] -columnspan 16 -pady 4
-	grid [label $w.fl -text {Foreground Colour}] -columnspan 16
-	incr row 4
-	foreach x {0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15} {
-	    grid [button $w.f$x -bg $mIRCCol($x) \
-	      -command "palIns {\003$x} {$chn} {$prt}"] -row $row -column $x
-	}
-	grid [frame $w.s2 ] -columnspan 16 -pady 4
-	grid [label $w.bl -text {Background Colour}] -columnspan 16
-	incr row 3
-	foreach x {0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15} {
-	    grid [button $w.b$x -bg $mIRCCol($x) \
-	      -command "bgIns $x {$chn} {$prt}"] -row $row -column $x
+    foreach c $col {
+        switch $c mirc {
+	    set row [colourBtns $w $row $chn $prt mIRCCol mIRC \
+	      palIns \003 {} bgIns {} {}]
+	} ansi {
+	    set row [colourBtns $w $row $chn $prt vt100Colour ANSI \
+	      palIns "\033\[3" m palIns "\033\[4" m]
+	    foreach {x y} {Bold 1 Inverse 7 Underline 4 Normal 0} {
+		button $w.v$x -text "ANSI\n$x" -width 10 \
+		-command "palIns [list \033\[${y}m] $chn {$prt}"
+	    }
+	    grid $w.vBold $w.vInverse $w.vUnderline $w.vNormal -columnspan 4
+	} ctcp2 {
 	}
     }
     grid [frame $w.s3] -columnspan 16 -pady 4
     grid [button $w.ok -text [trans dismiss] -command "destroy $w" -width 6] -columnspan 16
 }
 #
+proc colourBtns {w row chn prt var txt fgc fg1 fg2 bgc bg1 bg2} {
+    upvar #0 $var colrs
+    grid [frame $w.${var}s1] -columnspan 16 -pady 4
+    grid [label $w.${var}fl -text "$txt [trans {foreground colour}]"] -columnspan 16
+    incr row 4
+    set cls [lsort [array names colrs]]
+    set cl 0
+    set cinc [expr {16 / [llength $cls]}] 
+    foreach x $cls {
+        grid [button $w.$var$x -bg $colrs($x) \
+          -command "$fgc [list $fg1$x$fg2] $chn {$prt}"] \
+	  -row $row -column $cl -columnspan $cinc
+	incr cl $cinc
+    }
+    grid [frame $w.${var}s2 ] -columnspan 16 -pady 4
+    grid [label $w.${var}bl -text "$txt [trans {background colour}]"] -columnspan 16
+    incr row 3
+    set cl 0
+    foreach x $cls {
+        grid [button $w.${var}b$x -bg $colrs($x) \
+          -command "$bgc [list $bg1$x$bg2] $chn {$prt}"] \
+	  -row $row -column $cl -columnspan $cinc
+	incr cl $cinc
+    }
+    return $row
+}
+#
 proc fixList {lst} {
     set nl {}
     regsub -all {\\} $lst {\\\\} l1
