@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Window.tcl,v $
-# $Date: 1998/04/29 11:44:31 $
-# $Revision: 1.18.1.31 $
+# $Source: /home/nlfm/Zircon/lib/RCS/Window.tcl,v $
+# $Date: 1998/06/22 14:37:03 $
+# $Revision: 1.18.1.34 $
 #
 package provide zircon 1.18
 #
@@ -134,11 +134,37 @@ proc window_iconify {this} {
     foreach x [$this children] {[lindex $x 0] popdown }
 }
 #
+proc window_withdraw {this} {
+    wm withdraw [$this name]
+    foreach x [$this children] {[lindex $x 0] popdown }
+}
+#
+proc checkMainClose {} {
+    global zWClose zWInc zWList
+    set val 0
+    foreach x $zWList {
+        if {[$x closetime] != 0} {
+	    if {$val == 0 || [$x closetime] < $val} {
+	        set val [$x closetime]
+	    }
+	}
+    }
+    if {$val > 0} { set zWInc $val } { set zWInc 30000 }
+}
+#
 proc window_configure {this args} {
     upvar #0 $this wdata
     foreach {name val} $args {
 	set opt [string range $name 1 end]
 	switch -glob -- $name {
+	-closetime {
+		if {$val > 0} {
+		    if {$val < $wdata(closecount)} { set wdata(closecount) $val}
+		    set wdata(closetime) $val
+		} elseif {$val == 0} {
+		    set wdata(closetime) 0
+		}
+	    }
 	-title -
 	-iconname -
 	-iconbitmap { wm $opt [$this name] $val }
@@ -160,12 +186,13 @@ proc window_checkAllClose {this} {
     upvar #0 $this wdata
     set wdata(closetime) 0
     foreach x $wdata(children) { $this checkClose [lindex $x 0] }
+    checkMainClose
 }
 #
 proc window_checkClose {this id} {
     upvar #0 $this wdata
     if {[$id close]} {
-	if {$wdata(closetime) == 0 || [$id closemsec] > [expr {$wdata(closetime)/1000}]} {
+	if {$wdata(closetime) == 0 || [$id closemsec] < $wdata(closetime)} {
 	    $this configure -closetime [$id closemsec]
 	}
     }
@@ -197,7 +224,10 @@ proc Window_make {name} {
 proc window_inactive {this inc} {
     upvar #0 $this wdata
     if {$wdata(closetime) != 0} {
-	if {[incr wdata(closecount) $inc] <= 0} { $this iconify }
+	if {[incr wdata(closecount) $inc] <=0} {
+	    set wdata(closecount) 0
+	    $this [$this iconop]
+	}
     }
 }
 
