@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/misc2.tcl,v $
-# $Date: 1998/06/06 10:33:21 $
-# $Revision: 1.18.1.37 $
+# $Source: /home/nlfm/Zircon/lib/RCS/misc2.tcl,v $
+# $Date: 1998/06/13 20:35:44 $
+# $Revision: 1.18.1.38 $
 #
 #
 package provide zircon 1.18
@@ -84,7 +84,7 @@ proc ircII_/CTCP {net chid arg} {
     set nk [lindex $arg 0]
     switch * $nk {set nk [$chid name]}
     switch [set cmd [string toupper [lindex $arg 1]]] {
-    PING { $net CTCP PING $nk [ZPING] }
+    PING { $net CTCP PING $nk [zping] }
     CLIENTINFO {$net CTCP $cmd $nk [lindex $arg 2]}
     ERRMSG -
     SOUND -
